This function computes the lower bound for the number of true discoveries within each cluster (pathways) of Gene Expression Data.
pARIgene(X= NULL, pathways, alpha = 0.05, family = "simes", delta = 0,
B = 1000, test.type = "one_sample", complete = FALSE, iterative = FALSE,
approx = TRUE, ncomb = 100, step.down = FALSE, max.step = 10, ...)by default returns a list with the following objects:
lower bound for the number of true discoveries in the set selected
selected variables
If complete = TRUE the raw pvalues and cv critical vector are also returned.
Data matrix where rows represent the \(m\) variables and columns the \(n\) observations.
List of pathways where names indicates the name of the pathway.
Numeric value in `[0,1]`. \(\alpha\) level to control the family-wise error rate. Default to 0.05.
String character. Name of the family confidence envelope to compute the critical vector
from "simes", "aorc", "beta", "higher.criticism", and "power".
Default to "simes".
Numeric value. \(\delta\) value. Please see the reference below. Default to 0.
Numeric value. Number of permutations, default to 1000.
Character string. Choose a type of tests among "one_sample", i.e., one-sample t-tests, or "two_samples", i.e., two-samples t-tests. Default "one_sample".
Boolean value. If TRUE the sets of critical vectors and the raw \(p\)-values are returned. Default to FALSE.
Boolean value. If iterative = TRUE, the iterative method is applied (computationally demanding). Default to FALSE. Please see the reference below.
Boolean value. Default to TRUE. If you are analyzing high dimensional data, we suggest to put approx = TRUE to speed up the computation time. Please see the reference below.
Numeric value. If approx = TRUE, you must decide how many random sub collections (level of approximation) considered. Default to 100.
Boolean value. Default to FALSE If you want to compute the lambda calibration parameter using the step-down approach put TRUE. Please see the reference below.
Numeric value. Default to 10. Maximum number of steps for the step down approach, so useful when step.down = TRUE.
Further arguments
Angela Andreella
For the general framework of All-Resolutions Inference see:
Goeman, Jelle J., and Aldo Solari. "Multiple testing for exploratory research. " Statistical Science 26.4 (2011): 584-597.
For permutation-based All-Resolutions Inference see:
Andreella, A., Hemerik, J., Finos, L., Weeda, W., & Goeman, J. (2023). Permutation-based true discovery proportions for functional magnetic resonance imaging cluster analysis. Statistics in Medicine, 42(14), 2311-2340.
The type of tests implemented: signTest permTest.